@@ -41,12 +41,13 @@ use yansi::{Color, Paint, Style};
 use crate::{app::loadout_loop, cli::parse_cli_arguments};
 
 // Constants
-const DEFAULT_MASTER_FILE: &str = "config-master.toml";
-const MASTER_CONFIG_VAR: &str = "CONFIG_LOADER_CONFIG";
+const DEFAULT_CONFIG_FILE: &str = "loadouts-config.toml";
+const LOADOUTS_CONFIG_PATH_VAR: &str = "LOADOUTS_CONFIG_PATH";
 lazy_static! {
 	static ref MESSAGE_STYLE: Style = Style::new(Color::Cyan).wrap();
 	static ref HEADER_STYLE: Style = Style::new(Color::Yellow).bold();
 	static ref RESULT_STYLE: Style = Style::new(Color::Green).bold();
+	static ref ERROR_STYLE: Style = Style::new(Color::Red).bold();
 	static ref INPUT_STYLE: Style = Style::default().italic().dimmed();
 	static ref VALUE_STYLE: Style = Style::default().underline();
 }
@@ -54,28 +55,34 @@ lazy_static! {
 /// Entry Point.
 fn main() -> Result<()> {
 	let matches = parse_cli_arguments();
-	let master_file = matches
-		.value_of("master")
+	let config_file = matches
+		.value_of("loadouts")
 		.map(PathBuf::from)
-		.or_else(|| var(MASTER_CONFIG_VAR).ok().map(PathBuf::from))
-		.or_else(get_default_master_file)
-		.ok_or_else(|| Error::msg("unable to get a value for the master config file"))?;
-	let colour = matches.value_of("colour").expect("clap has betrayed us");
+		.or_else(|| var(LOADOUTS_CONFIG_PATH_VAR).ok().map(PathBuf::from))
+		.or_else(get_default_config_path)
+		.ok_or_else(|| Error::msg("unable to get a value for the loadouts config file"))?;
+	let colour = matches
+		.value_of("colour")
+		.expect("clap has betrayed us")
+		.to_lowercase();
 
-	if colour == "never" || (colour == "auto" && !Paint::enable_windows_ascii()) {
+	if colour.as_str() == "never" || (colour.as_str() == "auto" && !Paint::enable_windows_ascii()) {
 		Paint::disable();
 	}
 
 	println!(
 		"{} \"{}\"",
-		RESULT_STYLE.paint("Using master config file:"),
-		VALUE_STYLE.paint(master_file.display())
+		RESULT_STYLE.paint(format!(
+			"Config Loader v{}, using loadouts config file:",
+			env!("CARGO_PKG_VERSION")
+		)),
+		VALUE_STYLE.paint(config_file.display())
 	);
 
-	loadout_loop(master_file.as_path())
+	loadout_loop(config_file.as_path())
 }
 
-/// Fetches the path for the default master file.
-fn get_default_master_file() -> Option<PathBuf> {
-	home_dir().map(|dir| dir.join(DEFAULT_MASTER_FILE))
+/// Fetches the path for the default loadouts config.
+fn get_default_config_path() -> Option<PathBuf> {
+	home_dir().map(|dir| dir.join(DEFAULT_CONFIG_FILE))
 }
